.. _index_fr:

**********************************************************
:mod:`Euphorie` -- Euphorie outil d'évaluation des risques
**********************************************************

:Author: Simplon / Wichert Akkerman
:Version: |version|

Traductions
===========

Les traductions suivantes sont disponibles pour ce document:

:doc:`English <index>`
:doc:`Français <index_fr>`
Ελληνικά
Nederlands
:doc:`Deutsch <index_de>`


Sur
===

Euphorie est un outil d'évaluation des risques. Il a été développé par `SYSLAB`_ et `TNO`_
en coopération avec `Simplon`_ et `Cornelis Kolbach`_ en commission des
`L'Agence européenne pour la sécurité et la santé au travail`_ dans le cadre du
`Lieux de travail sains`_ campagne.

.. _syslab: http://syslab.com/
.. _TNO: http://www.tno.nl/index.cfm?Taal=2
.. _Simplon: http://www.simplon.biz/
.. _Cornelis Kolbach: http://cornae.org/
.. _The European Agency for Safety and Health at Work: http://osha.europa.eu/en/
.. _Healthy Workplaces: http://osha.europa.eu/en/campaigns/hw2008


Introduction
============

L'outil d'évaluation des risques euphorie est basée sur des questionnaires hiérarchique. Une
questionnaire (ou sondage) couvre tous les risques possibles pour un secteur spécifique de
l'industrie.

Chaque organisation du secteur peut avoir un ou plusieurs sondages publiés simultanément.
Afin de faciliter le développement et l'essai des enquêtes du système prend en charge
plusieurs versions d'une enquête. Seulement une version unique d'une enquête peut être
publique à tout moment.



Manuels
=======

.. toctree::
   :maxdepth: 1

   manuals/fr/why
   manuals/fr/creation-guide
   manuals/fr/client
   manuals/fr/admin
   manuals/fr/editor

Information Technique
=====================

.. toctree::
   :maxdepth: 1

   install
   xml
   implementation/index


Histoire des Changes
=====================

.. toctree::
  :maxdepth: 2

  changes



Indices et tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
